@@ -6,9 +6,9 @@ test_that("Whether filter SOR works", {
 
   pc <- pc_tree
 
-  to_SOR <- filter(pc, method = "SOR", k = 20, nSigma = 1, checks = 20)
+  to_SOR <- filter(pc, method = "SOR", k = 20, nSigma = 1)
 
-  expect_equal(nrow(to_SOR), 65946, info = "Number of points")
+  expect_equal(nrow(to_SOR), 64777, info = "Number of points")
   expect_equal(ncol(to_SOR), 3, info = "Number of columns")
 
 })
@@ -19,7 +19,7 @@ test_that("Whether filter min_neighbors works", {
                             Y = c(0, 0, 0, -1, 1, 0, 0),
                             Z = c(-1, 0, 1, 0, 0, 0, 0))
 
-  to_min <- filter(point_cloud, method = "min_neighbors", radius = 2, min_neighbours = 2)
+  to_min <- filter(point_cloud, method = "min_neighbors", radius = 1, min_neighbours = 2)
 
   expect_equal(nrow(to_min), 1, info = "Number of points")
   expect_equal(ncol(to_min), 3, info = "Number of columns")
@@ -37,6 +37,6 @@ test_that("Whether filter voxel_center works", {
 
   expect_equal(nrow(to_voxel), 1, info = "Number of points")
   expect_equal(ncol(to_voxel), 3, info = "Number of columns")
-  expect_equal(as.numeric(to_voxel[1,]), c(0, 1, 0), info = "Values")
+  expect_equal(as.numeric(to_voxel[1,]), c(0, 0, 0), info = "Values")
 
 })
